@@ -3,15 +3,16 @@ import abc
 import argparse
 import inspect
 
+import six
 
+
+@six.add_metaclass(abc.ABCMeta)
 class Command(object):
     """Base class for command plugins.
 
     :param app: Application instance invoking the command.
     :paramtype app: cliff.app.App
     """
-    __metaclass__ = abc.ABCMeta
-
     def __init__(self, app, app_args):
         self.app = app
         self.app_args = app_args
